@@ -50,9 +50,14 @@ typedef struct {
 } sv_with_hash;
 
 typedef struct {
-    SV *key;
-    SV *val;
-} kv_sv;
+    union {
+        SV *sv;
+    } key;
+    union {
+        HE *he;
+        SV *sv;
+    } val;
+} HE_SV;
 
 /* constructor from options */
 srl_encoder_t *srl_build_encoder_struct(pTHX_ HV *opt, sv_with_hash *options);
@@ -125,6 +130,8 @@ SV *srl_dump_data_structure_mortal_sv(pTHX_ srl_encoder_t *enc, SV *src, SV *use
 /* if set in flags, then do not use ARRAYREF or HASHREF ever */
 #define SRL_F_CANONICAL_REFS                    0x08000UL
 
+#define SRL_F_SORT_KEYS_PERL                    0x10000UL
+#define SRL_F_SORT_KEYS_PERL_REV                0x20000UL
 /* ====================================================================
  * oper flags
  */
